# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.7.2] - 2026-02-27

### Changed

- Change build backend from setuptools to hatchling.
- Change development status to "Alpha".

### Fixed

- Fix path finding in non-stable Flatpak apps. This covers e.g. nightly and beta packages.

## [0.7.1] - 2026-02-24

### Changed

- Change license to LGPL-3.0-or-later. Only a minor (patch) version bump as the new license is less restrictive than the previous AGPL-3.0-or-later.
- Clean up and refactor code into smaller modules for better maintainability.
- Update dependencies.

### Fixed

- Fix slow search when going through multiple directories by not creating a new Pool for each directory.

## [0.7.0] - 2025-12-24

### Added

- Add option "-a" to export all content from .mo files to a TSV file. Must be used in combination with -o, e.g. "<lang_code> -a -o tsv".
- Add option "-s" to search only in the source strings.
- Add option "-t" to search only in the translated strings.
- Add option "-w" to match only whole words.
- Add search summary and statistics to Rich output and TSV as comments.
- Add ty as a development dependency.

### Changed

- Do not allow empty search term by default. Use "<lang_code> -a -o tsv" instead.
- Non-ideal workaround: Force using "fork" instead of "spawn" in order to prevent a Pool being created on every directory search
  and thus being slow on Python 3.14t.

### Fixed

- Fix failing tests due to multiprocessing changes in Python 3.14. Fixes #5.

## [0.6.1] - 2025-11-09

### Changed

- Move development instructions from README.md to CONTRIBUTING.md.
- Python 3.14 support in classifiers.

### Fixed

- Remove .python-version file so that the runtime is not pinned.

## [0.6.0] - 2025-10-04

### Added

- Add support for Python package "wittrans".
- Build and publish package for distribution.
- Add option "-i" to highlight the search term in results.
- Add option "-f" to disable Flatpak search, and as such being much faster.
- Add option "--version" to show program version.

### Changed

- Restructure Python files, add wittrans.py.
- Tooling improvements: Make target additions and changes, EditorConfig added, more pre-commit hooks.
- Require Python 3.12, not 3.13. Older Python versions probably work but are not tested.
- Update development dependencies.

### Fixed

- Fix Rich crash when using search term "\n" only.

## [0.5.0] - 2025-08-31

### Added

- Improve search coverage from 6 to 14 paths by adding new paths for GNOME Extensions, KDE Plasmoids, and local installations.

### Changed

- Use multiprocessing when searching files. This will give a speed boost especially if there are lots of Flatpak apps.
- Update dependencies.

### Fixed

- Fix crash by escaping rich markup. This issue did not occur when using -o tsv.

## [0.4.0] - 2025-07-05

### Added

- Exporting of search results is now possible. Only TSV format is supported.
- Add REUSE.toml and correctly set SPDX license info.
- Add CHANGELOG.md.

### Changed

- Update Rich library to 14.0.0.
- Improve README.md.
- Change lint command and remove unused imports.

### Fixed

- Fix make targets.

## [0.3.2] - 2025-02-25

### Fixed

- Improve test coverage.

## [0.3.1] - 2025-02-25

### Fixed

- Update usage instructions and examples.

## [0.3.0] - 2025-02-16

### Added

- Support for ISO-639 Set-2 and Set-3 codes.
- Support for C locale codes.

## [0.2.1] - 2025-02-15

### Fixed

- Fix for searching inside Flatpak runtime.

## [0.2.0] - 2025-01-11

### Added

- Searching .mo file content inside Flatpak packages is now possible.

## [0.1.1] - 2024-12-22

### Added

- Add language codes.
- Add pytest unit tests.

## [0.1.0] - 2024-11-09

### Added

- First public version released on [Codeberg](https://codeberg.org/artnay/wittrans).
